@@ -41,8 +41,7 @@
 #' # Find summary statistics of the constricted interval
 #' Sum <- MinMaxLines(Sim1, clean = TRUE)
 #'
-#' @importFrom dplyr group_by_ ungroup mutate distinct_
-#' @import lazyeval
+#' @importFrom dplyr group_by ungroup mutate distinct across all_of pick
 #' @importFrom stats median quantile
 #' @keywords internals
 #' @export
@@ -60,7 +59,7 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE,
         byVars <- c("Time", "HRValue", "Strata")
     }
 
-    df <- group_by_(df, .dots = byVars)
+    df <- group_by(df, across(all_of(byVars)))
 
     if (!isTRUE(hr)){
         Linesdf <- mutate(df, Median = median(QI),
@@ -69,7 +68,7 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE,
                         Lower50 = quantile(QI, 0.25),
                         Upper50 = quantile(QI, 0.75))
 
-        Linesdf <- distinct_(Linesdf, .dots = byVars, .keep_all = TRUE)
+        Linesdf <- distinct(Linesdf, pick(all_of(byVars)), .keep_all = TRUE)
     }
     else if (isTRUE(hr) & !isTRUE(strata)){
         Linesdf <- mutate(df, Median = median(HRate),
@@ -78,8 +77,7 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE,
                           Lower50 = quantile(QI, 0.25),
                           Upper50 = quantile(QI, 0.75))
 
-        Linesdf <- distinct_(Linesdf, .dots = c(1, 3), .keep_all = TRUE)
-        #Linesdf <- Linesdf[!duplicated(Linesdf[, c(1, 3)]), ]
+        Linesdf <- distinct(Linesdf, pick(all_of(byVars)), .keep_all = TRUE)
     }
     else if (isTRUE(hr) & isTRUE(strata)){
         Linesdf <- mutate(df, Median = median(HRate),
